# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'mainwindow.ui'
#
# Created by: PyQt5 UI code generator 5.9.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtWidgets

from daplis_rtp.gui.live_timestamps_tab import LiveTimestamps
from daplis_rtp.gui.MZI_tab import MZI
from daplis_rtp.gui.single_pix_hist_tab import SinglePixelHistogram

# from graphic.delta_t_tab import Delta_t


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(899, 650)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(
            MainWindow.sizePolicy().hasHeightForWidth()
        )
        MainWindow.setSizePolicy(sizePolicy)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(
            self.centralwidget.sizePolicy().hasHeightForWidth()
        )
        self.centralwidget.setSizePolicy(sizePolicy)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.tabWidget = QtWidgets.QTabWidget(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(
            self.tabWidget.sizePolicy().hasHeightForWidth()
        )
        self.tabWidget.setSizePolicy(sizePolicy)
        self.tabWidget.setObjectName("tabWidget")
        # self.tab = QtWidgets.QWidget()
        self.tab = LiveTimestamps(self)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.tab.sizePolicy().hasHeightForWidth())
        self.tab.setSizePolicy(sizePolicy)
        self.tab.setObjectName("tab")
        self.gridLayout = QtWidgets.QGridLayout(self.tab)
        self.gridLayout.setObjectName("gridLayout")
        self.tabWidget.addTab(self.tab, "")
        # self.tab_2 = QtWidgets.QWidget()
        self.tab_2 = SinglePixelHistogram(self)
        self.tab_2.setObjectName("tab_2")
        self.tabWidget.addTab(self.tab_2, "")
        # self.tab_3 = QtWidgets.QWidget()
        # self.tab_3 = Delta_t(self)
        # self.tab_3.setObjectName("tab_3")
        # self.tabWidget.addTab(self.tab_3, "")
        self.tab_4 = MZI(self)
        self.tab_4.setObjectName("tab_4")
        self.tabWidget.addTab(self.tab_4, "")
        self.gridLayout_2.addWidget(self.tabWidget, 0, 0, 1, 1)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 899, 26))
        self.menubar.setObjectName("menubar")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)

        self.retranslateUi(MainWindow)
        self.tabWidget.setCurrentIndex(2)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(
            _translate("MainWindow", "LinoSPAD2 Data Analysis")
        )
        self.tabWidget.setTabText(
            self.tabWidget.indexOf(self.tab),
            _translate("MainWindow", "Online plot"),
        )
        self.tabWidget.setTabText(
            self.tabWidget.indexOf(self.tab_2),
            _translate("MainWindow", "Single Pixel Histogram"),
        )
        # self.tabWidget.setTabText(
        #     self.tabWidget.indexOf(self.tab_3), _translate("MainWindow", "Delta t")
        # )
        self.tabWidget.setTabText(
            self.tabWidget.indexOf(self.tab_4),
            _translate("MainWindow", "MZI"),
        )



"""This script generates the tab for single-pixel histograms.

The tab itself could be used for checking the LinoSPAD2 output for
homogeneity (the histogram should be more or less flat top).
"""

import glob
import os

from PyQt5 import QtCore, QtGui, QtWidgets, uic

from daplis_rtp.gui.single_pixel_histogram import HistCanvas


class SinglePixelHistogram(QtWidgets.QWidget):
    def __init__(self, parent=None):
        """Tab creation.

        The tab is created with combo boxes for LinoSPAD2 daughterboard
        number and firmware version, a spin box for the number of
        timestamps per pixel/TDC per cycle, and a spin box for the
        pixel number input. A 'browse' button with a line edit for
        choosing/inserting the file address is generated. A button for
        refreshing the plot is generated. The figure widget size is set
        constant across all tabs to achieve the same look for plots.
        An 'ui' file generated with Qt5 designer is used.

        """
        super().__init__(parent)

        os.chdir(r"gui/ui")
        uic.loadUi(
            r"SinglePixelHistogram_tab_c.ui",
            self,
        )
        os.chdir("../..")
        self.show()

        # Browse button signal
        self.pushButton_browse.clicked.connect(self.get_dir)

        # Histogram widget
        self.widget_figure = HistCanvas()
        # self.widget_figure.setFixedSize(500, 425)
        # self.widget_figure.setObjectName("widget")
        self.gridLayout.addWidget(self.widget_figure, 1, 0, 4, 3)

        # Refresh plot button signal
        self.pushButton_refreshPlot.clicked.connect(self.refresh_plot)

        # Set directory if path was pasted instead of chosen with the
        # 'Browse' button
        self.lineEdit_browse.textChanged.connect(self.change_path)

        # Standard cycle length is 4 ms
        self.cycle_length = 4e9

        self.lineEdit_cycleLength.editingFinished.connect(
            self.cycle_length_change
        )

    def get_dir(self):
        """Called when "browse" button is pressed.

        Path to where data files are saved to. Used for file searching and
        selecting.
        """
        self.folder = str(
            QtWidgets.QFileDialog.getExistingDirectory(
                self, "Select Directory"
            )
        )
        self.lineEdit_browse.setText(self.folder)

    def change_path(self):
        """Called when text is inserted to the browse line edit.

        Used for updating the path variable when text is inserted into
        the line edit.

        """
        self.folder = self.lineEdit_browse.text()

    def refresh_plot(self):
        """Button for refreshing the plot.

        Either refreshes the current plot or plots a new graph if new
        data were taken.

        """

        self.pix = self.spinBox_enterPixNumber.value()
        board_number = self.comboBox_boardNumber.currentText()
        timestamps = self.spinBox_timestamps.value()
        os.chdir(self.folder)

        files = glob.glob("*.dat*")

        try:
            last_file = max(files, key=os.path.getctime)
        except ValueError:
            msg_window = QtWidgets.QMessageBox()
            msg_window.setText(
                "No data files found, check the working directory."
            )
            msg_window.setWindowTitle("Error")
            msg_window.exec_()

        self.widget_figure.plot_hist(
            last_file,
            self.pix,
            timestamps,
            board_number,
            fw_ver=self.comboBox_FW.currentText(),
            cycle_length=self.cycle_length,
        )

    # Testing adaptive fontsize
    def resizeEvent(self, event):

        # Define minimum and maximum width and corresponding font sizes
        min_width = 908
        max_width = 3810
        min_fontsize = 16
        max_fontsize = 40

        # Get the current window width
        current_width = self.size().width()

        # Ensure the current width stays within the bounds
        current_width = max(min_width, min(max_width, current_width))

        # Calculate the new font size using linear interpolation
        new_font_size = min_fontsize + (
            (current_width - min_width) / (max_width - min_width)
        ) * (max_fontsize - min_fontsize)

        self.widget_figure._setplotparameters(fontsize=new_font_size)

        super().resizeEvent(event)

    def cycle_length_change(self):

        try:
            self.cycle_length = float(self.lineEdit_cycleLength.text())
        except ValueError:
            msg_window = QtWidgets.QMessageBox()
            msg_window.setText(
                "Cycle length should be a float, i.e., 4e9. Resetting "
                "to the default value."
            )
            msg_window.setWindowTitle("Error")
            msg_window.exec_()
            self.lineEdit_cycleLength.setText("4e9")
            self.cycle_length = 4e9



"""This script generates the tab for online photon count plotting.

Two pixels are chosen for which the photon count registered is plotted
side by side. Can be used in the Mach-Zehnder interferometer setup to
follow the changes of the photon counts in two pixels, or in other
setups for checking the stability.

"""

import glob
import os

import numpy as np
from PyQt5 import QtCore, QtWidgets, uic

from daplis_rtp.functions.sen_pop import sen_pop
from daplis_rtp.gui.plot_figure_MZI import PltCanvas_MZI


class MZI(QtWidgets.QWidget):
    def __init__(self, parent=None):
        """Creation of the tab.

        The tab is generated with a 'Browse' button along with a line
        edit field for choosing/inserting the address of the data
        file to plot. Combo boxes for LinoSPAD2 daughterboard number and
        the firmware version are generated. A check box for applying and
        a button for undoing the mask are generated. A spin box for
        the number of timestamps per pixel/TDC per cycle is provided.
        A check box for switching between a linear and a logarithmic
        scale of the plot is also provided. Buttons 'Refresh plot' for
        refreshing the plot and 'Start stream' for plotting the last
        file found are created. Two sliders for the left x-axis left
        limit and lower y-axis limit are provided.

        """
        super().__init__(parent)
        os.chdir(r"gui/ui")
        uic.loadUi(
            r"MZI_tab.ui",
            self,
        )
        os.chdir("../..")

        self.show()

        self.pathtotimestamp = ""

        # Browse button
        self.pushButton_browse.clicked.connect(self.get_dir)

        # Figure widget
        self.widget_figure = PltCanvas_MZI()
        # self.widget_figure.setMinimumSize(500, 400)
        # self.widget_figure.setFixedSize(500, 425)
        self.widget_figure.setObjectName("widget")
        self.gridLayout.addWidget(self.widget_figure, 1, 0, 4, 3)

        # Refresh plot and start stream buttons
        self.pushButton_refreshPlot.clicked.connect(self.slot_refresh)

        self.pushButton_startStream.clicked.connect(self.slot_startstream)

        # Set directory if path was pasted instead of chosen with the
        # 'Browse' button
        self.lineEdit_browse.textChanged.connect(self.change_path)

        # Count of dataset for using as x axis; raised by 1 when
        # update_time_stamp is called
        self.dataset_count = 0
        self.pix1 = 0
        self.pix2 = 0

        # Sliders
        self.horizontalSlider_leftXLim.valueChanged.connect(
            self.slot_updateLeftSlider
        )
        self.horizontalSlider_lowerXLim.valueChanged.connect(
            self.slot_updateLowerSlider
        )

        self.horizontalSlider_leftXLim.setMinimum(0)
        self.horizontalSlider_leftXLim.setMaximum(self.dataset_count)
        self.horizontalSlider_lowerXLim.setMinimum(0)
        self.horizontalSlider_lowerXLim.setMaximum(0)

        self.leftPosition = 0
        self.bottomPosition = 0

        # Browse button
        self.pushButton_Reset.clicked.connect(self.resetPlot)

        # Timer preset
        self.timer = QtCore.QTimer()
        self.timerRunning = False
        self.last_file_ctime = 0
        self.timer.timeout.connect(self.update_time_stamp)

    # Testing adaptive fontsize
    def resizeEvent(self, event):

        # Define minimum and maximum width and corresponding font sizes
        min_width = 908
        max_width = 3810
        min_fontsize = 16
        max_fontsize = 40

        # Get the current window width
        current_width = self.size().width()

        # Ensure the current width stays within the bounds
        current_width = max(min_width, min(max_width, current_width))

        # Calculate the new font size using linear interpolation
        new_font_size = min_fontsize + (
            (current_width - min_width) / (max_width - min_width)
        ) * (max_fontsize - min_fontsize)

        self.widget_figure.setplotparameters(fontsize=new_font_size)

        super().resizeEvent(event)

    def get_dir(self):
        """Called when the 'browse' button is pressed.

        Sets the path variable to the address chosen.

        """
        file = str(
            QtWidgets.QFileDialog.getExistingDirectory(
                self, "Select Directory"
            )
        )
        self.lineEdit_browse.setText(file)
        self.pathtotimestamp = file

    def change_path(self):
        """Called when address is inserted to the line edit.

        Sets the path variable to the address inserted.

        """
        self.pathtotimestamp = self.lineEdit_browse.text()

    def slot_startstream(self):
        """Called when the 'Start stream' button is pressed.

        Starts an infinite cycle of refreshing the plot when new files
        are found in the folder.

        """
        self.last_file_ctime = 0

        if self.timerRunning is True:
            self.timer.stop()
            self.timerRunning = False
            self.pushButton_startStream.setText("Start stream")
        else:
            self.pushButton_startStream.setText("Stop stream")
            self.timer.start(100)
            self.timerRunning = True

    def slot_stopstream(self):
        self.timer.stop()
        self.timerRunning = False
        self.pushButton_startStream.setText("Start stream")
        self.last_file_ctime = 0

    def slot_checkplotscale_2(self):
        """Called when state of the check box for scale is changed.

        Switches between logarithmic and linear scale of the plot.

        """
        if self.checkBox_presetMask_2.isChecked():
            self.widget_figure.setPlotScale(True)
        else:
            self.widget_figure.setPlotScale(False)

    def slot_refresh(self):
        """Called when the 'Refresh button' is pressed.

        Refreshes the plot, either the current one or updates with the
        new data if new data were taken.

        """
        self.update_time_stamp()
        self.last_file_ctime = 0

    def slot_updateLeftSlider(self):
        """Called when left slider state has changed.

        Updates the left x-axis limit based on the position of the
        slider.

        """
        self.leftPosition = self.horizontalSlider_leftXLim.value()

    def slot_updateLowerSlider(self):
        """Called when left slider state has changed.

        Updates the left x-axis limit based on the position of the
        slider.

        """
        self.bottomPosition = self.horizontalSlider_lowerXLim.value()

    def resetPlot(self):
        self.widget_figure.ax.cla()
        self.widget_figure.ax2.cla()
        self.dataset_count = 0
        self.widget_figure.figure.canvas.draw()
        self.widget_figure.figure.canvas.flush_events()

    def update_time_stamp(self):
        """Called during the cycle of real-time plotting.

        Load data from the last data file found in the directory
        provided.

        """
        stopping = False
        os.chdir(self.pathtotimestamp)
        DATA_FILES = glob.glob("*.dat*")
        try:
            last_file = max(DATA_FILES, key=os.path.getctime)
            new_file_ctime = os.path.getctime(last_file)
        except ValueError:
            msg_window = QtWidgets.QMessageBox()
            msg_window.setText(
                "No data files found, check the working directory."
            )
            msg_window.setWindowTitle("Error")
            msg_window.exec_()
            self.slot_stopstream()
            stopping = True
        if stopping is False:
            try:
                if new_file_ctime > self.last_file_ctime:
                    self.dataset_count += 1
                    self.horizontalSlider_leftXLim.setMaximum(
                        self.dataset_count
                    )
                    self.last_file_ctime = new_file_ctime

                    validtimestamps = sen_pop(
                        self.pathtotimestamp + "/" + last_file,
                        board_number=self.comboBox_mask_2.currentText(),
                        fw_ver=self.comboBox_FW_2.currentText(),
                        timestamps=self.spinBox_timestamps_2.value(),
                        pix_add_fix=self.checkBox_pix_add_fix.isChecked(),
                    )

                    self.widget_figure.setPlotData_MZI(
                        [self.dataset_count - 1, self.dataset_count],
                        [
                            self.pix1,
                            validtimestamps[self.spinBox_FirstPixel.value()],
                        ],
                        [
                            self.pix2,
                            validtimestamps[self.spinBox_SecondPixel.value()],
                        ],
                        self.leftPosition,
                        self.bottomPosition,
                    )
                    self.pix1 = validtimestamps[
                        self.spinBox_FirstPixel.value()
                    ]
                    self.pix2 = validtimestamps[
                        self.spinBox_SecondPixel.value()
                    ]
                    self.horizontalSlider_lowerXLim.setMaximum(
                        int(np.max([self.pix1, self.pix2]))
                    )

            except ValueError:
                msg_window = QtWidgets.QMessageBox()
                msg_window.setText(
                    "Cannot unpack data, check the timestamp setting and "
                    "the firmware version."
                )
                msg_window.setWindowTitle("Error")
                msg_window.exec_()
                self.slot_stopstream()
                stopping = True

    # Testing adaptive fontsize
    def resizeEvent(self, event):

        # Define minimum and maximum width and corresponding font sizes
        min_width = 908
        max_width = 3810
        min_fontsize = 16
        max_fontsize = 40

        # Get the current window width
        current_width = self.size().width()

        # Ensure the current width stays within the bounds
        current_width = max(min_width, min(max_width, current_width))

        # Calculate the new font size using linear interpolation
        new_font_size = min_fontsize + (
            (current_width - min_width) / (max_width - min_width)
        ) * (max_fontsize - min_fontsize)

        self.widget_figure.setplotparameters(fontsize=new_font_size)

        super().resizeEvent(event)



import os
import unittest

from daplis_rtp.functions import sen_pop


class SenPopTestCase(unittest.TestCase):
    def setUp(self):
        self.path = "tests/test_data"
        self.board_number = "A5"
        self.fw_ver = "2212b"
        self.timestamps = 200

    def test_sen_pop_positive(self):
        # Positive test case
        work_dir = r"{}".format(os.path.realpath(__file__) + "../../..")
        os.chdir(work_dir)
        file = r"tests/test_data/test_data_2212b.dat"

        data = sen_pop.sen_pop(
            file, self.board_number, self.fw_ver, self.timestamps
        )

        self.assertTrue(data.any())


if __name__ == "__main__":
    unittest.main()



import os
import unittest

import numpy as np

from daplis_rtp.functions.unpack import unpack_bin


class TestUnpackBin(unittest.TestCase):
    def test_unpack_pos(self):
        # Positive test case
        work_dir = r"{}".format(os.path.realpath(__file__) + "../../..")
        os.chdir(work_dir)
        file = r"tests/test_data/test_data_2212b.dat"
        board_number = "A5"
        fw_ver = "2212b"
        timestamps = 200

        data = unpack_bin(file, board_number, fw_ver, timestamps)

        self.assertEqual(data.shape, (64, 4020, 2))
        self.assertEqual(data.dtype, np.longlong)


if __name__ == "__main__":
    unittest.main()



""" Class for hooking the widgets to the main window for the LinoSPAD2 data
analysis and visualization application.

"""

from PyQt5.QtWidgets import QWidget, QTabWidget, QVBoxLayout
from app.graphic.tab_livetimestamps import LiveTimestamps
from app.graphic.tab_single_pixel_histogram import SinglePixelHistogram
import matplotlib

matplotlib.use("Qt5Agg")


class TableWidget(QWidget):
    def __init__(self, parent):
        """
        Class initialization. Widgets 'LiveHistogram' and
        'SinglePixelHistogram' will be initialized.

        Parameters
        ----------
        parent : basestring
            Class being inherited from.

        Returns
        -------
        None.

        """
        super(QWidget, self).__init__(parent)
        self.layout = QVBoxLayout(self)

        # Initialize tab screen
        self.tabs = QTabWidget()

        self.tab1 = LiveTimestamps(self)
        self.tab2 = SinglePixelHistogram()
        # self.tabs.resize(300, 200)

        # Add tabs
        self.tabs.addTab(self.tab1, "Live timestamps")
        self.tabs.addTab(self.tab2, "Single pixel histogram")

        self.layout.addWidget(self.tabs)
        self.setLayout(self.layout)



"""Module for plotting single pixel histograms.

The main usage is checking the homogeneity of the LinoSPAD2 output. The
output graph should be flat top.

"""

import sys

import matplotlib.pyplot as plt
import numpy as np
from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg
from matplotlib.backends.backend_qt5agg import (
    NavigationToolbar2QT as NavigationToolbar,
)
from matplotlib.figure import Figure
from PyQt5.QtWidgets import QVBoxLayout, QWidget

from daplis_rtp.functions.unpack import unpack_bin


class HistCanvas(QWidget):
    def __init__(self, parent=None, width=7, height=4, dpi=100):
        """Figure widget initialization.

        The figure is initialized with the matplotlib navigation panel for
        more control over the plot.

        Parameters
        ----------
        width : int, optional
            Figure widget width, by default 7.
        height : int, optional
            Figure widget height, by default 4.
        dpi : int, optional
            Figure widget dpi, by default 100.
        """
        super(HistCanvas, self).__init__(parent)

        # figure initialization
        self.figure = Figure(figsize=(width, height), dpi=100)
        self.canvas = FigureCanvasQTAgg(self.figure)

        self.toolbar = NavigationToolbar(self.canvas, self)
        self.ax = self.figure.add_subplot(111)
        self.figure.subplots_adjust(
            left=0.15, right=0.97, top=0.945, bottom=0.12
        )

        # creating a Vertical Box layout
        self.layout = QVBoxLayout(self)
        self.layout.addWidget(self.canvas)
        self.layout.addWidget(self.toolbar)

        self.setLayout(self.layout)

        self._setplotparameters()

    def _setplotparameters(self, fontsize: int = 16):
        """Figure parameters manipulation.

        Set font size, axes labels. Set the width and orientation of the
        axes ticks.

        """
        plt.rcParams.update({"font.size": fontsize})
        self.ax.set_xlabel("Pixel (-)", fontsize=fontsize)
        self.ax.set_ylabel("# of timestamps (-)", fontsize=fontsize)

        self.ax.tick_params(which="both", width=2, direction="in")
        self.ax.tick_params(
            which="major", length=7, direction="in", labelsize=fontsize
        )
        self.ax.tick_params(
            which="minor", length=4, direction="in", labelsize=fontsize
        )
        self.ax.yaxis.set_ticks_position("both")
        self.ax.xaxis.set_ticks_position("both")

        for axis in ["top", "bottom", "left", "right"]:
            self.ax.spines[axis].set_linewidth(2)

    def plot_hist(
        self,
        file: str,
        pixel: int,
        timestamps: int,
        board_number: str,
        fw_ver: str,
        cycle_length: float,
    ):
        """Plot histogram.

        Plots a histogram of timestamps for a single pixel. Bin size is
        set to 17.867 us.

        Parameters
        ----------
        file : str
            Data file address.
        pixel : int
            Pixel number to plot a histogram for.
        timestamps : int
            Number of timestamps per pixel/TDC per acquisition cycle.
        board_number : str
            LinoSPAD2 daughterboard number.
        fw_ver : str
            LinoSPAD2 firmware version.
        """
        data = unpack_bin(file, board_number, fw_ver, timestamps)

        bin_rounder = cycle_length / (2500 / 140) / 250

        bins = np.arange(0, cycle_length, 2500 / 140 * bin_rounder)

        self.ax.cla()

        if fw_ver == "2208":
            self.ax.hist(data[pixel], bins=bins, color="teal")
        elif fw_ver[:-1] == "2212":
            if fw_ver == "2212s":
                pix_coor = np.arange(256).reshape(4, 64).T
            elif fw_ver == "2212b":
                pix_coor = np.arange(256).reshape(64, 4)
            tdc, pix = np.argwhere(pix_coor == pixel)[0]
            ind = np.where(data[tdc].T[0] == pix)[0]
            ind1 = np.where(data[tdc].T[1][ind] > 0)[0]
            data_to_plot = data[tdc].T[1][ind[ind1]]

            self.ax.hist(data_to_plot, bins=bins, color="teal")
        else:
            print("\nFirmware version is not recognized, exiting.")
            sys.exit()

        self.ax.set_xlabel("Time (ps)")
        self.ax.set_ylabel("# of timestamps (-)")
        # self.ax.set_title("Pixel {}, 17.867 us bin".format(pixel))
        self.ax.set_xlim(0, cycle_length + 100)
        # self.ax.ticklabel_format(axis="y", style="sci", scilimits=(0, 0))
        self.canvas.draw()
        self.canvas.flush_events()
